Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(230)

Unified Diff: pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart

Issue 1497523004: move dart completion contributor instantiation (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: merge and address comments Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analysis_server/lib/src/services/completion/dart/completion_manager.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart
diff --git a/pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart b/pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart
index 7a21bbb66137fd30b655964c0d14f6330265405b..d5085c80b5d4114183a855267fab4e7c3b69a9b1 100644
--- a/pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart
+++ b/pkg/analysis_server/lib/src/provisional/completion/dart/completion_plugin.dart
@@ -38,11 +38,11 @@ class DartCompletionPlugin implements Plugin {
String get uniqueIdentifier => UNIQUE_IDENTIFIER;
/**
* Return a list containing all of the Dart specific completion contributor
* factories that were contributed.
*/
- List<DartCompletionContributorFactory> get contributorFactories =>
- _contributorExtensionPoint.extensions;
+ Iterable<DartCompletionContributorFactory> get contributors =>
+ _contributorExtensionPoint.extensions
+ .map((DartCompletionContributorFactory factory) => factory());
@override
void registerExtensionPoints(RegisterExtensionPoint registerExtensionPoint) {
« no previous file with comments | « no previous file | pkg/analysis_server/lib/src/services/completion/dart/completion_manager.dart » ('j') | no next file with comments »
@@ -38,11 +38,11 @@ class DartCompletionPlugin implements Plugin {
String get uniqueIdentifier => UNIQUE_IDENTIFIER;
/**
- * Return a list containing all of the Dart specific completion contributor
- * factories that were contributed.
+ * Return a list containing all of the Dart specific completion contributors.
*/

Powered by Google App Engine
This is Rietveld 408576698